@@ -108,6 +108,7 @@ class MecabNer(MecabDataController):
 
     MIN_MEANING = 2
     NER_POS = "ner"
+    ENTITY_POS_LIST = ["NNG", "NNP", "NNB", "NNBC", "NR", "NP", "XSN", "XR", "SL", "SH", "SN", "UNKNOWN"]
     INFER_ENTITY_POS_LIST = ["NNG", "NNP"]
 
     def __init__(self, ner_path: str = None, search_category: List = None, infer=True, clear_mecab_dir=True):
@@ -165,6 +166,11 @@ class MecabNer(MecabDataController):
         if (len(m_p_d.pattern) >= m_p_d.min_meaning) and space_token_contain_pattern:
             for pattern_item in space_token_contain_pattern:
 
+                pattern_end_pos = m_p_d.sentence[pattern_item[END_IDX] - 1][MECAB_FEATURE].pos
+
+                if pattern_end_pos not in self.ENTITY_POS_LIST and len(m_p_d.pattern) < self.MIN_MEANING:
+                    continue
+
                 _prevent_compound_token(pattern_item, m_p_d.sentence)
 
                 yield MecabWordCategory(category=m_p_d.category,
